/*
 * kdingsystray.cpp
 *
 * Copyright (c) 2005 Michael Rex <me@rexi.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "translatedialog.h"
#include "kdingsystray.h"
#include "kding.h"
#include "kdingconfig.h"
#include <kiconloader.h>
#include <kkeydialog.h>
#include <klocale.h>
#include <kglobalaccel.h>
#include <khelpmenu.h>
#include <kpopupmenu.h>
#include <kconfigdialog.h>
#include <qclipboard.h>
#include <qpixmap.h>
#include <qtooltip.h>
#include <qevent.h>

/**
 *
 */
KDingSysTray::KDingSysTray(QWidget* parent, const char* name) : KSystemTray(parent, name), dialog(0) {
    setPixmap(loadIcon("kding"));
    
    QToolTip::add(this, i18n("KDing - translation tool"));

    // init global shortcuts
    accel = new KGlobalAccel(this);
    accel->insert("translateClipboard", i18n("Translate clipboard contents"),
        i18n("Translates the current content of the clipboard or selection."),
        KKey::QtWIN+SHIFT+Key_T, CTRL+SHIFT+Key_T, this, SLOT(translate()));
    accel->insert("translateGivenWord", i18n("Open translation dialog"),
        i18n("Opens a dialog where you can enter the word to be translated."),
        KKey::QtWIN+SHIFT+Key_W, CTRL+SHIFT+Key_W, this, SLOT(translateWord()));

    // load user shortcut settings
    accel->readSettings();
    accel->updateConnections();
    
    menu = contextMenu();
    menu->insertItem(SmallIcon("babelfish"), i18n("&Translate"), this, SLOT(translate()));
    menu->insertItem(SmallIcon("babelfish"), i18n("Translate &word..."), this, SLOT(translateWord()));
    menu->insertSeparator();
    //menu->insertItem(SmallIcon("configure"), i18n("Configure KDing..."), this, SLOT(showConfig()));
    menu->insertItem(SmallIcon("configure_shortcuts"), i18n("Configure &global shortcuts..."), this, SLOT(showShortcuts()));
    menu->insertSeparator();
    
    help = new KHelpMenu(this, kapp->aboutData(), false);
    menu->insertItem(SmallIcon("help"), i18n("&Help"), help->menu());
    
    dialog = new TranslateDialog(this);
}

KDingSysTray::~KDingSysTray() {
    delete dialog;
}

/*
 * public slots
 */

void KDingSysTray::translate() {
    QClipboard* cb = KApplication::clipboard();
    dialog->clearDialog();
    dialog->translate(cb->text(QClipboard::Selection));
    dialog->show();
}

void KDingSysTray::translateWord() {
    if(!dialog->isVisible()) {
        dialog->show();
    } else {
        dialog->hide();
        dialog->show();
    }
}

void KDingSysTray::showShortcuts() {
    KKeyDialog::configure(accel);
    accel->writeSettings();
}

void KDingSysTray::showConfig() {
    if(KConfigDialog::showDialog("settings")) {
        return;
    }
    
    KConfigDialog* cfgdialog = new KConfigDialog(this, "settings", KDingConfig::self(), KDialogBase::IconList);
    //cfgdialog->addPage(new General(0, "General"), i18n("General") );
    //cfgdialog->addPage(new Appearance(0, "Style"), i18n("Appearance") );
    //connect(dialog, SIGNAL(settingsChanged()), mainWidget, SLOT(loadSettings()));
    //connect(dialog, SIGNAL(settingsChanged()), this, SLOT(loadSettings()));
    cfgdialog->show();
}


/*
 * protected methods
 */

/**
 * Overridden to change behaviour of left mouse button.
 * @param e 
 */
void KDingSysTray::mousePressEvent(QMouseEvent* e) {
    switch(e->button()) {
        case LeftButton:
            translate();
            break;
        case MidButton:
            translateWord();
            break;
        default:
            KSystemTray::mousePressEvent(e);
            break;
    }
}
